<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>フィルタ:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../../forms/fontdialog.ui" line="14"/>
        <location filename="../../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>ターミナルフォントの選択</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>フォント:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>サイズ:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="330"/>
        <source>&amp;Close Tab</source>
        <translation>タブを閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="232"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>ターミナルの上下分割(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="211"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>アクティブなターミナルをクリアする(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="235"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>ターミナルの左右分割(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="240"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>サブターミナルを折りたたむ(&amp;C)</translation>
    </message>
    <message>
        <source>N&amp;ext Subterminal</source>
        <translation type="vanished">次のサブターミナル(&amp;E)</translation>
    </message>
    <message>
        <source>P&amp;revious Subterminal</source>
        <translation type="vanished">前のサブターミナル(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="218"/>
        <source>&amp;Next Tab</source>
        <translation>次のタブ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="221"/>
        <source>&amp;Previous Tab</source>
        <translation>前のタブ(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="224"/>
        <source>Move Tab &amp;Left</source>
        <translation>タブを左へ移動(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="227"/>
        <source>Move Tab &amp;Right</source>
        <translation>タブを右へ移動(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <source>&amp;Top Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="246"/>
        <source>&amp;Bottom Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="249"/>
        <source>L&amp;eft Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="252"/>
        <source>R&amp;ight Subterminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="259"/>
        <source>Copy &amp;Selection</source>
        <translation>選択部分をコピー(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="265"/>
        <source>Paste S&amp;election</source>
        <translation>選択部分を貼り付け(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="287"/>
        <source>&amp;Save Session</source>
        <translation>セッションを保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="293"/>
        <source>&amp;Load Session</source>
        <translation>セッションを読出(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="305"/>
        <source>Rename session</source>
        <translation>セッション名の変更</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="317"/>
        <source>New Tab From &amp;Preset</source>
        <translation>新規タブをプリセットで開く(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="318"/>
        <source>1 &amp;Terminal</source>
        <translation>画面分割なし(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="320"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>上下２分割(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="322"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>左右２分割(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="324"/>
        <source>4 Terminal&amp;s</source>
        <translation>４分割(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="338"/>
        <source>&amp;Preferences...</source>
        <translation>設定(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="342"/>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="373"/>
        <source>Toggle Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="381"/>
        <source>&amp;Bottom</source>
        <translation>下(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="382"/>
        <source>&amp;Top</source>
        <translation>上(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="383"/>
        <location filename="../../mainwindow.cpp" line="419"/>
        <source>&amp;Right</source>
        <translation>右(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="384"/>
        <location filename="../../mainwindow.cpp" line="420"/>
        <source>&amp;Left</source>
        <translation>左(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="402"/>
        <source>&amp;Tabs Layout</source>
        <translation>タブの位置(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="418"/>
        <source>&amp;None</source>
        <translation>なし(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="436"/>
        <source>S&amp;crollbar Layout</source>
        <translation>スクロールバーの位置(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="449"/>
        <source>&amp;BlockCursor</source>
        <translation>ブロックカーソル(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="450"/>
        <source>&amp;UnderlineCursor</source>
        <translation>アンダーラインカーソル(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="451"/>
        <source>&amp;IBeamCursor</source>
        <translation>アイビームカーソル(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="468"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>カーソルの形(&amp;K)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="558"/>
        <source>Exit QTerminal</source>
        <translation>QTerminal終了</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="560"/>
        <source>Do not ask again</source>
        <translation>次から確認しない</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="568"/>
        <source>Are you sure you want to exit?</source>
        <translation>終了してもよろしいですか?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="598"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>軽量マルチプラットフォーム ターミナルエミュレータ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="79"/>
        <source>Bookmarks</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation type="vanished">タブ名の変更</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="171"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>&quot;%1&quot;を押すとそのターミナルを見ることができます</translation>
    </message>
    <message>
        <source>&amp;Clear Current Tab</source>
        <translation type="vanished">現在のタブをクリア(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Paste Clip&amp;board</source>
        <translation>クリップボードの貼り付け(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="268"/>
        <source>Zoom &amp;in</source>
        <translation>ズームイン(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="271"/>
        <source>Zoom &amp;out</source>
        <translation>ズームアウト(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="274"/>
        <source>Zoom rese&amp;t</source>
        <translation>ズームリセット(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="279"/>
        <source>&amp;Find...</source>
        <translation>検索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="300"/>
        <source>&amp;Toggle Menu</source>
        <translation>メニューの表示/非表示(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="313"/>
        <source>&amp;New Tab</source>
        <translation>新規タブ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="333"/>
        <source>&amp;New Window</source>
        <translation>新規ウィンドウ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="348"/>
        <source>&amp;Hide Window Borders</source>
        <translation>ウィンドウ枠を隠す(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="359"/>
        <source>&amp;Show Tab Bar</source>
        <translation>タブを表示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="367"/>
        <source>Fullscreen</source>
        <translation>フルスクリーン</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="432"/>
        <source>Emulation</source>
        <translation>エミュレーション</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="62"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>ターミナルの設定</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="52"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="57"/>
        <location filename="../../forms/propertiesdialog.ui" line="457"/>
        <source>Behavior</source>
        <translation>挙動</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="67"/>
        <source>Dropdown</source>
        <translation>ドロップダウン</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="100"/>
        <source>Color scheme</source>
        <translation>配色</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="296"/>
        <source>Widget style</source>
        <translation>ウィジェットのスタイル</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="110"/>
        <source>Scrollbar position</source>
        <translation>スクロールバーの位置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="267"/>
        <source>Tabs position</source>
        <translation>タブの位置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="319"/>
        <source>Show the menu bar</source>
        <translation>メニューバーの表示</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="136"/>
        <source>Show a border around the current terminal</source>
        <translation>カレントターミナルの境界を表示</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="153"/>
        <source>Application transparency</source>
        <translation>アプリケーションの透過</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="143"/>
        <source>Terminal transparency</source>
        <translation>ターミナルの透過</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="120"/>
        <source>Start with preset:</source>
        <translation>プリセットでスタート:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="164"/>
        <source>None (single terminal)</source>
        <translation>画面分割なし</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="169"/>
        <source>2 terminals horizontally</source>
        <translation>上下２分割</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="174"/>
        <source>2 terminals vertically</source>
        <translation>左右２分割</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="179"/>
        <source>4 terminals</source>
        <translation>４分割</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="218"/>
        <source>Font</source>
        <translation>フォント</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="326"/>
        <source>Keyboard cursor shape</source>
        <translation>カーソルの形</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="336"/>
        <source>Change window title based on current terminal</source>
        <translation>現在のターミナルのウィンドウタイトルの変更</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="343"/>
        <source>Change window icon based on current terminal</source>
        <translation>現在のターミナルのアイコンの変更</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="350"/>
        <source>Enable bi-directional text support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="357"/>
        <source>Background image:</source>
        <translation>背景画像:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="369"/>
        <source>Select</source>
        <translation>選択</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="378"/>
        <source>Show terminal size on resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="385"/>
        <source>Limit tab width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="395"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="405"/>
        <source>Show close button on each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="441"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;エミュレータの挙動の選択。注意して頂きたいのは、この選択はオペレーティングシステムと適合する必要はありません。&lt;/p&gt;&lt;p&gt; &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt;エミュレーションは最小の機能にフォールバックしたものです。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="463"/>
        <source>Action after paste</source>
        <translation>貼り付け後の挙動</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="473"/>
        <source>Confirm multiline paste</source>
        <translation>複数にまたがる行の貼り付けの確認</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="480"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>テキストの貼付け時に空白の行を生成しない</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="513"/>
        <source>Open new terminals in current working directory</source>
        <translation>カレントディレクトリに新しいターミナルを開く</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="520"/>
        <source>Save Size when closing</source>
        <translation>閉じるときにサイズを保存する</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="527"/>
        <source>Save Position when closing</source>
        <translation>閉じるときに位置を保存する</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="534"/>
        <source>Ask for confirmation when closing</source>
        <translation>閉じるときに確認する</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="544"/>
        <source>Unlimited history</source>
        <translation>履歴を制限しない</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="551"/>
        <source>History size (in lines)</source>
        <translation>履歴 (行数)</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="558"/>
        <source>Default $TERM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="572"/>
        <source>xterm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="577"/>
        <source>xterm-256color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="649"/>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="659"/>
        <location filename="../../forms/propertiesdialog.ui" line="676"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="666"/>
        <source>Width</source>
        <translation>幅</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="722"/>
        <source>Edit bookmark file contents</source>
        <translation>ブックマークの内容を編集する</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="744"/>
        <source>Enable bookmarks</source>
        <translation>ブックマークを利用可能にする</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="753"/>
        <source>Bookmark file</source>
        <translation>ブックマークファイル</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="187"/>
        <location filename="../../forms/propertiesdialog.ui" line="280"/>
        <source> %</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="614"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="619"/>
        <source>Key</source>
        <translation>キー割当</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="72"/>
        <source>Bookmarks</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="90"/>
        <source>Hide tab bar with only one tab</source>
        <translation>1つのタブしか使用していない場合、タブバーを隠す</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="254"/>
        <source>&amp;Change...</source>
        <translation>変更（&amp;C)...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="631"/>
        <source>Show on start</source>
        <translation>起動時に表示します</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="638"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="690"/>
        <source>Shortcut:</source>
        <translation>ショートカット:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="766"/>
        <source>Find...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="775"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>ブックマークファイルの場所を指定することができます。OwnCloudやDropboxのようなツールとブックマークを共有することが容易にできます。</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <source>No scrollbar</source>
        <translation>スクロールバーなし</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>BlockCursor</source>
        <translation>ブロックカーソル</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>UnderlineCursor</source>
        <translation>アンダーラインカーソル</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>IBeamCursor</source>
        <translation>アイビームカーソル</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>No move</source>
        <translation type="unfinished">無動作</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move start</source>
        <translation type="unfinished">動作開始</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move end</source>
        <translation type="unfinished">動作終了</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="129"/>
        <location filename="../../propertiesdialog.cpp" line="199"/>
        <source>System Default</source>
        <translation>システムの既定</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="282"/>
        <source>Choose a background image</source>
        <translation>背景画像を選択</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="283"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation>画像 (*.bmp *.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="348"/>
        <source>Open or create bookmarks file</source>
        <translation>ブックマークファイルを開く、または新規作成</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../../termwidget.cpp" line="237"/>
        <source>Show Details...</source>
        <translation>詳細を表示...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="110"/>
        <source>Local Bookmarks</source>
        <translation>ローカルブックマーク</translation>
    </message>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="168"/>
        <source>Synchronized Bookmarks</source>
        <translation>ブックマークの同期</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../../tabwidget.cpp" line="73"/>
        <location filename="../../tabwidget.cpp" line="219"/>
        <source>Shell No. %1</source>
        <translation>Shell No. %1</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="187"/>
        <source>Tab name</source>
        <translation>タブの名前</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="188"/>
        <source>New tab name:</source>
        <translation>タブの新しい名前:</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="208"/>
        <source>Select new tab title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="229"/>
        <source>Close session</source>
        <translation>タブを閉じる</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="231"/>
        <source>Change title color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename session</source>
        <translation type="vanished">タブ名の変更</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../../termwidgetholder.cpp" line="78"/>
        <source>Load Session</source>
        <translation>セッションの読込</translation>
    </message>
    <message>
        <location filename="../../termwidgetholder.cpp" line="79"/>
        <source>List of saved sessions:</source>
        <translation>保存されたセッションリスト:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../../termwidget.cpp" line="229"/>
        <source>Paste multiline text</source>
        <translation>複数行のテキストを貼り付け</translation>
    </message>
    <message>
        <location filename="../../termwidget.cpp" line="230"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>テキストを貼り付けますか?</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>操作(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>QTerminalについて(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Qtについて(&amp;Q)...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="vanished">設定(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="vanished">終了(&amp;Q)</translation>
    </message>
</context>
</TS>
